import { __decorate, __metadata } from 'tslib';
import { EventEmitter, Input, Output, Component, ViewChild, ViewChildren, forwardRef, QueryList, ChangeDetectorRef, ComponentFactoryResolver, ContentChildren, HostBinding, ViewContainerRef, ChangeDetectionStrategy, NgModule } from '@angular/core';
import { FormGroup, ReactiveFormsModule } from '@angular/forms';
import { DynamicFormControlComponent, DynamicFormLayoutService, DynamicFormValidationService, DynamicCheckboxModel, DynamicCheckboxGroupModel, DynamicDatePickerModel, DynamicFormGroupComponent, DynamicFormGroupModel, DynamicInputModel, DynamicRadioGroupModel, DynamicRatingModel, DynamicSelectModel, DynamicTextAreaModel, DynamicTimePickerModel, DynamicFormControlContainerComponent, DynamicFormComponentService, DynamicFormRelationService, DynamicTemplateDirective, DynamicFormArrayGroupModel, DynamicFormControlModel, DYNAMIC_FORM_CONTROL_TYPE_TIMEPICKER, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA, DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_RATING, DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP, DYNAMIC_FORM_CONTROL_TYPE_INPUT, DYNAMIC_FORM_CONTROL_TYPE_GROUP, DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX, DYNAMIC_FORM_CONTROL_TYPE_ARRAY, DynamicFormArrayComponent, DynamicFormArrayModel, DynamicFormComponent, DynamicFormsCoreModule } from '@ng-dynamic-forms/core';
import { BsDatepickerDirective, BsDatepickerModule } from 'ngx-bootstrap/datepicker';
import { TimepickerComponent, TimepickerModule } from 'ngx-bootstrap/timepicker';
import { CommonModule } from '@angular/common';
import { ButtonsModule } from 'ngx-bootstrap/buttons';
import { RatingModule } from 'ngx-bootstrap/rating';
import { TextMaskModule } from 'angular2-text-mask';

let DynamicNGxBootstrapCheckboxComponent = class DynamicNGxBootstrapCheckboxComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapCheckboxComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapCheckboxComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapCheckboxComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapCheckboxComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicCheckboxModel)
], DynamicNGxBootstrapCheckboxComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapCheckboxComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapCheckboxComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapCheckboxComponent.prototype, "focus", void 0);
DynamicNGxBootstrapCheckboxComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-checkbox",
        template: "<div [formGroup]=\"group\" class=\"form-check\" [class.disabled]=\"model.disabled\">\n\n    <label class=\"form-check-label\">\n\n        <input type=\"checkbox\" class=\"form-check-input\"\n               [checked]=\"model.checked\"\n               [class.is-invalid]=\"showErrorMessages\"\n               [formControlName]=\"model.id\"\n               [id]=\"id\"\n               [indeterminate]=\"model.indeterminate\"\n               [name]=\"model.name\"\n               [ngClass]=\"getClass('element', 'control')\"\n               [required]=\"model.required\"\n               [tabindex]=\"model.tabIndex\"\n               [value]=\"model.value\"\n               (blur)=\"onBlur($event)\"\n               (change)=\"onChange($event)\"\n               (focus)=\"onFocus($event)\"/><span [innerHTML]=\"model.label\"\n                                                [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"></span>\n    </label>\n\n</div>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapCheckboxComponent);

let DynamicNGxBootstrapCheckboxGroupComponent = class DynamicNGxBootstrapCheckboxGroupComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
    getCheckboxId(model) {
        return this.layoutService.getElementId(model);
    }
};
DynamicNGxBootstrapCheckboxGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapCheckboxGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapCheckboxGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapCheckboxGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicCheckboxGroupModel)
], DynamicNGxBootstrapCheckboxGroupComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapCheckboxGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapCheckboxGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapCheckboxGroupComponent.prototype, "focus", void 0);
DynamicNGxBootstrapCheckboxGroupComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-checkbox-group",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div class=\"btn-group\"\n         [formGroupName]=\"model.id\"\n         [id]=\"id\"\n         [ngClass]=\"getClass('element', 'control')\">\n\n        <label *ngFor=\"let checkboxModel of model.group\" btnCheckbox class=\"btn\" role=\"button\"\n               [class.active]=\"checkboxModel.value\"\n               [formControlName]=\"checkboxModel.id\"\n               [id]=\"getCheckboxId(checkboxModel)\"\n               [innerHTML]=\"checkboxModel.label\"\n               [ngClass]=\"[getClass('element', 'control', checkboxModel)]\"></label>\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapCheckboxGroupComponent);

let DynamicNGxBootstrapDatePickerComponent = class DynamicNGxBootstrapDatePickerComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapDatePickerComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapDatePickerComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapDatePickerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapDatePickerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicDatePickerModel)
], DynamicNGxBootstrapDatePickerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapDatePickerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapDatePickerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapDatePickerComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapDatePickerComponent.prototype, "focus", void 0);
__decorate([
    ViewChild(BsDatepickerDirective, { static: true }),
    __metadata("design:type", BsDatepickerDirective)
], DynamicNGxBootstrapDatePickerComponent.prototype, "bsDatePicker", void 0);
DynamicNGxBootstrapDatePickerComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-datepicker",
        template: "<div [formGroup]=\"group\" class=\"input-group\">\n\n    <input bsDatepicker class=\"form-control\" #bsDatepicker=\"bsDatepicker\"\n           [autofocus]=\"model.autoFocus\"\n           [bsConfig]=\"model.getAdditional('bsConfig', {containerClass: model.getAdditional('containerClass', 'theme-green'), showWeekNumbers: model.getAdditional('showWeekNumbers', true)})\"\n           [datesDisabled]=\"model.getAdditional('datesDisabled', [])\"\n           [daysDisabled]=\"model.getAdditional('daysDisabled', [])\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [maxDate]=\"model.max\"\n           [minDate]=\"model.min\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [outsideClick]=\"model.getAdditional('outsideClick', true)\"\n           [outsideEsc]=\"model.getAdditional('outsideEsc', true)\"\n           [placeholder]=\"model.placeholder\"\n           [placement]=\"model.getAdditional('placement', 'bottom')\"\n           [readonly]=\"model.readOnly\"\n           [required]=\"model.required\"\n           (bsValueChange)=\"onChange($event)\"\n           (onHidden)=\"onCustomEvent($event, 'onHidden')\"\n           (onShown)=\"onCustomEvent($event, 'onShown')\">\n\n    <div *ngIf=\"model.toggleIcon || model.toggleLabel\" class=\"input-group-append\">\n\n        <button *ngIf=\"model.toggleIcon\"\n                class=\"btn input-group-text\" type=\"button\"\n                (click)=\"bsDatepicker.toggle()\"><img [src]=\"model.toggleIcon\"/></button>\n        <button *ngIf=\"model.toggleLabel\"\n                class=\"btn input-group-text\" type=\"button\"\n                (click)=\"bsDatepicker.toggle()\">{{ model.toggleLabel }}</button>\n\n    </div>\n\n</div>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapDatePickerComponent);

let DynamicNGxBootstrapFormGroupComponent = class DynamicNGxBootstrapFormGroupComponent extends DynamicFormGroupComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapFormGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapFormGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormGroupModel)
], DynamicNGxBootstrapFormGroupComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormGroupComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormGroupComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormGroupComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicNGxBootstrapFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicNGxBootstrapFormGroupComponent.prototype, "components", void 0);
DynamicNGxBootstrapFormGroupComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-form-group",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div role=\"group\" [formGroupName]=\"model.id\" [id]=\"id\" [ngClass]=\"getClass('element','control')\">\n\n        <dynamic-ngx-bootstrap-form-control *ngFor=\"let _model of model.group\"\n                                            [asBootstrapFormGroup]=\"true\"\n                                            [group]=\"control\"\n                                            [hidden]=\"_model.hidden\"\n                                            [layout]=\"formLayout\"\n                                            [model]=\"_model\"\n                                            [templates]=\"templates\"\n                                            [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                            (blur)=\"onBlur($event)\"\n                                            (change)=\"onChange($event)\"\n                                            (focus)=\"onFocus($event)\"\n                                            (bsEvent)=\"onCustomEvent($event, null, true)\"></dynamic-ngx-bootstrap-form-control>\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapFormGroupComponent);

let DynamicNGxBootstrapInputComponent = class DynamicNGxBootstrapInputComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapInputComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapInputComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapInputComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapInputComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicInputModel)
], DynamicNGxBootstrapInputComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapInputComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapInputComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapInputComponent.prototype, "focus", void 0);
DynamicNGxBootstrapInputComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-input",
        template: "<div [formGroup]=\"group\" [class.input-group]=\"model.prefix || model.suffix\">\n\n    <div *ngIf=\"model.prefix\" class=\"input-group-prepend\">\n        <span class=\"input-group-text\" [innerHTML]=\"model.prefix\"></span>\n    </div>\n\n    <input [attr.accept]=\"model.accept\"\n           [attr.max]=\"model.max\"\n           [attr.min]=\"model.min\"\n           [attr.multiple]=\"model.multiple\"\n           [attr.step]=\"model.step\"\n           [autocomplete]=\"model.autoComplete\"\n           [autofocus]=\"model.autoFocus\"\n           [class.form-control]=\"model.inputType !== 'file'\"\n           [class.form-control-file]=\"model.inputType === 'file'\"\n           [class.is-invalid]=\"showErrorMessages\"\n           [dynamicList]=\"model.listId\"\n           [formControlName]=\"model.id\"\n           [id]=\"id\"\n           [maxlength]=\"model.maxLength\"\n           [minlength]=\"model.minLength\"\n           [name]=\"model.name\"\n           [ngClass]=\"getClass('element', 'control')\"\n           [pattern]=\"model.pattern\"\n           [placeholder]=\"model.placeholder\"\n           [readonly]=\"model.readOnly\"\n           [required]=\"model.required\"\n           [spellcheck]=\"model.spellCheck\"\n           [tabindex]=\"model.tabIndex\"\n           [textMask]=\"{mask: (model.mask || false), showMask: model.mask && !(model.placeholder)}\"\n           [type]=\"model.inputType\"\n           (blur)=\"onBlur($event)\"\n           (change)=\"onChange($event)\"\n           (focus)=\"onFocus($event)\"/>\n\n    <div *ngIf=\"model.suffix\" class=\"input-group-append\">\n        <span class=\"input-group-text\" [innerHTML]=\"model.suffix\"></span>\n    </div>\n\n    <datalist *ngIf=\"model.hasList\" [id]=\"model.listId\">\n\n        <option *ngFor=\"let option of model.list$ | async\" [value]=\"option\">\n\n    </datalist>\n\n</div>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapInputComponent);

let DynamicNGxBootstrapRadioGroupComponent = class DynamicNGxBootstrapRadioGroupComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapRadioGroupComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapRadioGroupComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapRadioGroupComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapRadioGroupComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicRadioGroupModel)
], DynamicNGxBootstrapRadioGroupComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapRadioGroupComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapRadioGroupComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapRadioGroupComponent.prototype, "focus", void 0);
DynamicNGxBootstrapRadioGroupComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-radio-group",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div btnRadioGroup class=\"btn-group\" role=\"radiogroup\"\n         [formControlName]=\"model.id\"\n         [id]=\"id\"\n         [ngClass]=\"getClass('element', 'control')\"\n         [tabindex]=\"model.tabIndex\"\n         (change)=\"onChange($event)\">\n\n        <label *ngFor=\"let option of model.options$ | async\" class=\"btn\" role=\"button\"\n               [btnRadio]=\"option.value\"\n               [disabled]=\"option.disabled\"\n               [innerHTML]=\"option.label\"\n               [ngClass]=\"[getClass('element', 'option'), getClass('grid', 'option')]\"></label>\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapRadioGroupComponent);

let DynamicNGxBootstrapRatingComponent = class DynamicNGxBootstrapRatingComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapRatingComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapRatingComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapRatingComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapRatingComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicRatingModel)
], DynamicNGxBootstrapRatingComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapRatingComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapRatingComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapRatingComponent.prototype, "focus", void 0);
DynamicNGxBootstrapRatingComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-rating",
        template: "<ng-container [formGroup]=\"group\">\n\n    <rating [formControlName]=\"model.id\"\n            [id]=\"id\"\n            [max]=\"model.max\"\n            [ngClass]=\"getClass('element', 'control')\"\n            [readonly]=\"model.getAdditional('readonly', false)\"\n            (onHover)=\"onCustomEvent($event, 'onHover')\"\n            (onLeave)=\"onCustomEvent($event, 'onLeave')\"></rating>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapRatingComponent);

let DynamicNGxBootstrapSelectComponent = class DynamicNGxBootstrapSelectComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapSelectComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapSelectComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapSelectComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapSelectComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicSelectModel)
], DynamicNGxBootstrapSelectComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapSelectComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapSelectComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapSelectComponent.prototype, "focus", void 0);
DynamicNGxBootstrapSelectComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-select",
        template: "<ng-container [formGroup]=\"group\">\n\n    <select class=\"form-control\"\n            [class.is-invalid]=\"showErrorMessages\"\n            [compareWith]=\"model.compareWithFn\"\n            [formControlName]=\"model.id\"\n            [id]=\"id\"\n            [name]=\"model.name\"\n            [ngClass]=\"getClass('element', 'control')\"\n            [required]=\"model.required\"\n            [tabindex]=\"model.tabIndex\"\n            (blur)=\"onBlur($event)\"\n            (change)=\"onChange($event)\"\n            (focus)=\"onFocus($event)\">\n\n        <option *ngFor=\"let option of model.options$ | async\"\n                [disabled]=\"option.disabled\"\n                [ngValue]=\"option.value\">{{ option.label }}</option>\n\n    </select>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapSelectComponent);

let DynamicNGxBootstrapTextAreaComponent = class DynamicNGxBootstrapTextAreaComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapTextAreaComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapTextAreaComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapTextAreaComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapTextAreaComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicTextAreaModel)
], DynamicNGxBootstrapTextAreaComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapTextAreaComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapTextAreaComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapTextAreaComponent.prototype, "focus", void 0);
DynamicNGxBootstrapTextAreaComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-textarea",
        template: "<ng-container [formGroup]=\"group\">\n\n    <textarea class=\"form-control\"\n              [class.is-invalid]=\"showErrorMessages\"\n              [cols]=\"model.cols\"\n              [formControlName]=\"model.id\"\n              [id]=\"id\"\n              [maxlength]=\"model.maxLength\"\n              [minlength]=\"model.minLength\"\n              [name]=\"model.name\"\n              [ngClass]=\"getClass('element', 'control')\"\n              [placeholder]=\"model.placeholder\"\n              [readonly]=\"model.readOnly\"\n              [required]=\"model.required\"\n              [rows]=\"model.rows\"\n              [spellcheck]=\"model.spellCheck\"\n              [tabindex]=\"model.tabIndex\"\n              [wrap]=\"model.wrap\"\n              (blur)=\"onBlur($event)\"\n              (change)=\"onChange($event)\"\n              (focus)=\"onFocus($event)\"></textarea>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapTextAreaComponent);

let DynamicNGxBootstrapTimePickerComponent = class DynamicNGxBootstrapTimePickerComponent extends DynamicFormControlComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapTimePickerComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapTimePickerComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapTimePickerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapTimePickerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicTimePickerModel)
], DynamicNGxBootstrapTimePickerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapTimePickerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapTimePickerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapTimePickerComponent.prototype, "focus", void 0);
__decorate([
    ViewChild(TimepickerComponent, { static: true }),
    __metadata("design:type", TimepickerComponent)
], DynamicNGxBootstrapTimePickerComponent.prototype, "bsTimePicker", void 0);
DynamicNGxBootstrapTimePickerComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-timepicker",
        template: "<ng-container [formGroup]=\"group\">\n\n    <timepicker [arrowkeys]=\"model.getAdditional('arrowkeys', true)\"\n                [formControlName]=\"model.id\"\n                [hourStep]=\"model.getAdditional('hourStep', 1)\"\n                [id]=\"id\"\n                [max]=\"model.max\"\n                [min]=\"model.min\"\n                [mousewheel]=\"model.getAdditional('mousewheel', true)\"\n                [minuteStep]=\"model.getAdditional('minuteStep', 1)\"\n                [ngClass]=\"getClass('element', 'control')\"\n                [secondsStep]=\"model.getAdditional('secondsStep', 1)\"\n                [showMeridian]=\"model.meridian\"\n                [showSeconds]=\"model.showSeconds\"\n                [showSpinners]=\"model.getAdditional('spinners', true)\"></timepicker>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapTimePickerComponent);

let DynamicNGxBootstrapFormControlContainerComponent = class DynamicNGxBootstrapFormControlContainerComponent extends DynamicFormControlContainerComponent {
    constructor(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService) {
        super(changeDetectorRef, componentFactoryResolver, layoutService, validationService, componentService, relationService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.componentService = componentService;
        this.relationService = relationService;
        this.asBootstrapFormGroup = true;
        this.context = null;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.customEvent = new EventEmitter();
    }
    get componentType() {
        return this.componentService.getCustomComponentType(this.model) || bootstrapUIFormControlMapFn(this.model);
    }
};
DynamicNGxBootstrapFormControlContainerComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ComponentFactoryResolver },
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService },
    { type: DynamicFormComponentService },
    { type: DynamicFormRelationService }
];
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "contentTemplateList", void 0);
__decorate([
    HostBinding("class"),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "klass", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "asBootstrapFormGroup", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayGroupModel)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "context", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "hostClass", void 0);
__decorate([
    Input("templates"),
    __metadata("design:type", QueryList)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "inputTemplateList", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormControlModel)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "model", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "focus", void 0);
__decorate([
    Output("bsEvent"),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "customEvent", void 0);
__decorate([
    ViewChild("componentViewContainer", { read: ViewContainerRef, static: true }),
    __metadata("design:type", ViewContainerRef)
], DynamicNGxBootstrapFormControlContainerComponent.prototype, "componentViewContainerRef", void 0);
DynamicNGxBootstrapFormControlContainerComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-form-control",
        template: "<div [class.form-group]=\"(model.type !== 'GROUP' && asBootstrapFormGroup) || getClass('element', 'container').includes('form-group')\"\n     [formGroup]=\"group\"\n     [ngClass]=\"['ng-dynamic-forms-'+model.type.toLowerCase(), getClass('element', 'container'), getClass('grid', 'container')]\">\n\n    <label *ngIf=\"!isCheckbox && hasLabel\"\n           [for]=\"id\"\n           [innerHTML]=\"model.label\"\n           [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"></label>\n\n    <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: model\"></ng-container>\n\n    <div [ngClass]=\"getClass('grid', 'control')\">\n\n        <ng-container #componentViewContainer></ng-container>\n\n        <small *ngIf=\"hasHint\" class=\"text-muted\" [innerHTML]=\"hint\" [ngClass]=\"getClass('element', 'hint')\"></small>\n\n        <div *ngIf=\"showErrorMessages\" [ngClass]=\"[getClass('element', 'errors'), getClass('grid', 'errors')]\">\n            <small *ngFor=\"let message of errorMessages\" class=\"invalid-feedback d-block\">{{ message }}</small>\n        </div>\n\n    </div>\n\n    <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: model\"></ng-container>\n\n    <ng-content></ng-content>\n\n</div>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        ComponentFactoryResolver,
        DynamicFormLayoutService,
        DynamicFormValidationService,
        DynamicFormComponentService,
        DynamicFormRelationService])
], DynamicNGxBootstrapFormControlContainerComponent);
function bootstrapUIFormControlMapFn(model) {
    switch (model.type) {
        case DYNAMIC_FORM_CONTROL_TYPE_ARRAY:
            return DynamicNGxBootstrapFormArrayComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX:
            return DynamicNGxBootstrapCheckboxComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP:
            return DynamicNGxBootstrapCheckboxGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER:
            return DynamicNGxBootstrapDatePickerComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_GROUP:
            return DynamicNGxBootstrapFormGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_INPUT:
            return DynamicNGxBootstrapInputComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP:
            return DynamicNGxBootstrapRadioGroupComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_RATING:
            return DynamicNGxBootstrapRatingComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_SELECT:
            return DynamicNGxBootstrapSelectComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA:
            return DynamicNGxBootstrapTextAreaComponent;
        case DYNAMIC_FORM_CONTROL_TYPE_TIMEPICKER:
            return DynamicNGxBootstrapTimePickerComponent;
        default:
            return null;
    }
}

let DynamicNGxBootstrapFormArrayComponent = class DynamicNGxBootstrapFormArrayComponent extends DynamicFormArrayComponent {
    constructor(layoutService, validationService) {
        super(layoutService, validationService);
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.customEvent = new EventEmitter();
        this.focus = new EventEmitter();
    }
};
DynamicNGxBootstrapFormArrayComponent.ctorParameters = () => [
    { type: DynamicFormLayoutService },
    { type: DynamicFormValidationService }
];
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormArrayComponent.prototype, "formLayout", void 0);
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapFormArrayComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormArrayComponent.prototype, "layout", void 0);
__decorate([
    Input(),
    __metadata("design:type", DynamicFormArrayModel)
], DynamicNGxBootstrapFormArrayComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", QueryList)
], DynamicNGxBootstrapFormArrayComponent.prototype, "templates", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormArrayComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormArrayComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormArrayComponent.prototype, "customEvent", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormArrayComponent.prototype, "focus", void 0);
__decorate([
    ViewChildren(forwardRef(() => DynamicNGxBootstrapFormControlContainerComponent)),
    __metadata("design:type", QueryList)
], DynamicNGxBootstrapFormArrayComponent.prototype, "components", void 0);
DynamicNGxBootstrapFormArrayComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-form-array",
        template: "<ng-container [formGroup]=\"group\">\n\n    <div [formArrayName]=\"model.id\" [id]=\"id\" [ngClass]=\"getClass('element', 'control')\">\n\n        <div *ngFor=\"let groupModel of model.groups; let idx = index\" role=\"group\"\n             [formGroupName]=\"idx\" [ngClass]=\"[getClass('element', 'group'), getClass('grid', 'group')]\">\n\n            <ng-container *ngTemplateOutlet=\"startTemplate?.templateRef; context: groupModel\"></ng-container>\n\n            <dynamic-ngx-bootstrap-form-control *ngFor=\"let _model of groupModel.group\"\n                                                [context]=\"groupModel\"\n                                                [group]=\"array.at(idx)\"\n                                                [hidden]=\"_model.hidden\"\n                                                [layout]=\"formLayout\"\n                                                [model]=\"_model\"\n                                                [templates]=\"templates\"\n                                                [hostClass]=\"[getClass('element','children'), getClass('grid','children')]\"\n                                                (blur)=\"onBlur($event)\"\n                                                (change)=\"onChange($event)\"\n                                                (focus)=\"onFocus($event)\"\n                                                (bsEvent)=\"onCustomEvent($event, null, true)\"></dynamic-ngx-bootstrap-form-control>\n\n            <ng-container *ngTemplateOutlet=\"endTemplate?.templateRef; context: groupModel\"></ng-container>\n\n        </div>\n\n    </div>\n\n</ng-container>\n"
    }),
    __metadata("design:paramtypes", [DynamicFormLayoutService,
        DynamicFormValidationService])
], DynamicNGxBootstrapFormArrayComponent);

let DynamicNGxBootstrapFormComponent = class DynamicNGxBootstrapFormComponent extends DynamicFormComponent {
    constructor(changeDetectorRef, componentService) {
        super(changeDetectorRef, componentService);
        this.changeDetectorRef = changeDetectorRef;
        this.componentService = componentService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.bsEvent = new EventEmitter();
    }
};
DynamicNGxBootstrapFormComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DynamicFormComponentService }
];
__decorate([
    Input(),
    __metadata("design:type", FormGroup)
], DynamicNGxBootstrapFormComponent.prototype, "group", void 0);
__decorate([
    Input(),
    __metadata("design:type", Array)
], DynamicNGxBootstrapFormComponent.prototype, "model", void 0);
__decorate([
    Input(),
    __metadata("design:type", Object)
], DynamicNGxBootstrapFormComponent.prototype, "layout", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormComponent.prototype, "blur", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormComponent.prototype, "change", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormComponent.prototype, "focus", void 0);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], DynamicNGxBootstrapFormComponent.prototype, "bsEvent", void 0);
__decorate([
    ContentChildren(DynamicTemplateDirective),
    __metadata("design:type", QueryList)
], DynamicNGxBootstrapFormComponent.prototype, "templates", void 0);
__decorate([
    ViewChildren(DynamicNGxBootstrapFormControlContainerComponent),
    __metadata("design:type", QueryList)
], DynamicNGxBootstrapFormComponent.prototype, "components", void 0);
DynamicNGxBootstrapFormComponent = __decorate([
    Component({
        selector: "dynamic-ngx-bootstrap-form",
        template: "<dynamic-ngx-bootstrap-form-control *ngFor=\"let controlModel of model; trackBy: trackByFn\"\n                                    [group]=\"group\"\n                                    [hidden]=\"controlModel.hidden\"\n                                    [layout]=\"layout\"\n                                    [model]=\"controlModel\"\n                                    [templates]=\"templates\"\n                                    (blur)=\"onBlur($event)\"\n                                    (change)=\"onChange($event)\"\n                                    (focus)=\"onFocus($event)\"\n                                    (bsEvent)=\"onCustomEvent($event, bsEvent)\"></dynamic-ngx-bootstrap-form-control>\n",
        changeDetection: ChangeDetectionStrategy.OnPush
    }),
    __metadata("design:paramtypes", [ChangeDetectorRef,
        DynamicFormComponentService])
], DynamicNGxBootstrapFormComponent);

let DynamicFormsNGxBootstrapUIModule = class DynamicFormsNGxBootstrapUIModule {
};
DynamicFormsNGxBootstrapUIModule = __decorate([
    NgModule({
        imports: [
            CommonModule,
            ReactiveFormsModule,
            BsDatepickerModule,
            ButtonsModule,
            RatingModule,
            TimepickerModule,
            TextMaskModule,
            DynamicFormsCoreModule
        ],
        declarations: [
            DynamicNGxBootstrapCheckboxComponent,
            DynamicNGxBootstrapCheckboxGroupComponent,
            DynamicNGxBootstrapDatePickerComponent,
            DynamicNGxBootstrapFormArrayComponent,
            DynamicNGxBootstrapFormComponent,
            DynamicNGxBootstrapFormControlContainerComponent,
            DynamicNGxBootstrapFormGroupComponent,
            DynamicNGxBootstrapInputComponent,
            DynamicNGxBootstrapRadioGroupComponent,
            DynamicNGxBootstrapRatingComponent,
            DynamicNGxBootstrapSelectComponent,
            DynamicNGxBootstrapTextAreaComponent,
            DynamicNGxBootstrapTimePickerComponent
        ],
        entryComponents: [
            DynamicNGxBootstrapCheckboxComponent,
            DynamicNGxBootstrapCheckboxGroupComponent,
            DynamicNGxBootstrapDatePickerComponent,
            DynamicNGxBootstrapFormArrayComponent,
            DynamicNGxBootstrapFormGroupComponent,
            DynamicNGxBootstrapInputComponent,
            DynamicNGxBootstrapRadioGroupComponent,
            DynamicNGxBootstrapRatingComponent,
            DynamicNGxBootstrapSelectComponent,
            DynamicNGxBootstrapTextAreaComponent,
            DynamicNGxBootstrapTimePickerComponent
        ],
        exports: [
            DynamicFormsCoreModule,
            DynamicNGxBootstrapCheckboxComponent,
            DynamicNGxBootstrapCheckboxGroupComponent,
            DynamicNGxBootstrapDatePickerComponent,
            DynamicNGxBootstrapFormArrayComponent,
            DynamicNGxBootstrapFormComponent,
            DynamicNGxBootstrapFormControlContainerComponent,
            DynamicNGxBootstrapFormGroupComponent,
            DynamicNGxBootstrapInputComponent,
            DynamicNGxBootstrapRadioGroupComponent,
            DynamicNGxBootstrapRatingComponent,
            DynamicNGxBootstrapSelectComponent,
            DynamicNGxBootstrapTextAreaComponent,
            DynamicNGxBootstrapTimePickerComponent
        ]
    })
], DynamicFormsNGxBootstrapUIModule);

/**
 * Generated bundle index. Do not edit.
 */

export { DynamicFormsNGxBootstrapUIModule, DynamicNGxBootstrapCheckboxComponent, DynamicNGxBootstrapCheckboxGroupComponent, DynamicNGxBootstrapDatePickerComponent, DynamicNGxBootstrapFormArrayComponent, DynamicNGxBootstrapFormComponent, DynamicNGxBootstrapFormControlContainerComponent, DynamicNGxBootstrapFormGroupComponent, DynamicNGxBootstrapInputComponent, DynamicNGxBootstrapRadioGroupComponent, DynamicNGxBootstrapRatingComponent, DynamicNGxBootstrapSelectComponent, DynamicNGxBootstrapTextAreaComponent, DynamicNGxBootstrapTimePickerComponent, bootstrapUIFormControlMapFn };
//# sourceMappingURL=ui-ngx-bootstrap.js.map
